LoggedUniformTotalOrderBroadcast

Struct LoggedUniformTotalOrderBroadcast 

pub struct LoggedUniformTotalOrderBroadcast<V: Clone + Ord> { /* private fields */ }
A totally ordered log whose sequence survives a restart.

Implementations

Source

impl<V: Clone + Ord> LoggedUniformTotalOrderBroadcast<V>

pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, timing: Timing, ) -> Self

A totally ordered log among peers whose sequence survives a restart.

pub fn entries(&self) -> &[OrderedSlot<V>] ⓘ

The agreed sequence as this process holds it.

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn round(&self) -> u64

pub fn instances(&self) -> usize