pub struct LoggedUniformTotalOrderBroadcast<V: Clone + Ord> { /* private fields */ }Expand description
A totally ordered log whose sequence survives a restart.
Implementations
Sourceimpl<V: Clone + Ord> LoggedUniformTotalOrderBroadcast<V>
impl<V: Clone + Ord> LoggedUniformTotalOrderBroadcast<V>
Sourcepub fn new(
me: NodeId,
peers: impl IntoIterator<Item = NodeId>,
timing: Timing,
) -> Self
pub fn new( me: NodeId, peers: impl IntoIterator<Item = NodeId>, timing: Timing, ) -> Self
A totally ordered log among peers whose sequence survives a restart.
Sourcepub fn entries(&self) -> &[OrderedSlot<V>] ⓘ
pub fn entries(&self) -> &[OrderedSlot<V>] ⓘ
The agreed sequence as this process holds it.
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn round(&self) -> u64
pub fn instances(&self) -> usize